containertools.get_first_container_in_improper_parentage_of_component
=====================================================================

.. autofunction:: abjad.tools.containertools.get_first_container_in_improper_parentage_of_component
